==> zio-aws-kafka_2.13-5.17.104.13-sources.jar: zio/aws/kafka/model/ClusterOperationStepInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterOperationStepInfo(stepStatus: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo = {
    import ClusterOperationStepInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
      .builder()
      .optionallyWith(
        stepStatus.map(value => __string.unwrap(value): java.lang.String)
      )(_.stepStatus)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly =
    zio.aws.kafka.model.ClusterOperationStepInfo.wrap(buildAwsValue())
}
object ClusterOperationStepInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ClusterOperationStepInfo =
      zio.aws.kafka.model
        .ClusterOperationStepInfo(stepStatus.map(value => value))
    def stepStatus: Option[__string]
    def getStepStatus: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("stepStatus", stepStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ) extends zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly {
    override val stepStatus: Option[__string] = scala
      .Option(impl.stepStatus())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ): zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.153.2-sources.jar: zio/aws/kafka/model/ClusterOperationStepInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClusterOperationStepInfo(stepStatus: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo = {
    import ClusterOperationStepInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
      .builder()
      .optionallyWith(stepStatus.map(value => value: java.lang.String))(
        _.stepStatus
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly =
    zio.aws.kafka.model.ClusterOperationStepInfo.wrap(buildAwsValue())
}
object ClusterOperationStepInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ClusterOperationStepInfo =
      zio.aws.kafka.model
        .ClusterOperationStepInfo(stepStatus.map(value => value))
    def stepStatus: Option[__string]
    def getStepStatus: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("stepStatus", stepStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ) extends zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly {
    override val stepStatus: Option[__string] =
      scala.Option(impl.stepStatus()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ClusterOperationStepInfo
  ): zio.aws.kafka.model.ClusterOperationStepInfo.ReadOnly = new Wrapper(impl)
}
